import network
import socket
import time
import machine

ssid = 'your_ssid'
password = 'your_password'

pico_led = machine.Pin("LED", machine.Pin.OUT)
sensor_temp = machine.ADC(4)
conversion_factor = 3.3 / (65535)
temperature = 0

def connect():
    #Connect to WLAN
    wlan = network.WLAN(network.STA_IF)
    wlan.active(True)
    wlan.connect(ssid, password)
    while wlan.isconnected() == False:
        print('Waiting for connection...')
        time.sleep(1)
    ip = wlan.ifconfig()[0]
    print(f'Connected on {ip}')
    for i in range(5): 
        pico_led.value(1)
        time.sleep(0.5)
        pico_led.value(0)
        time.sleep(0.5)
    return ip


def open_socket(ip):
    # Open a socket
    address = (ip, 80)
    connection = socket.socket()
    connection.bind(address)
    connection.listen(1)
    return connection

def webpage(temperature):
    #Template HTML
    html = f"""
            <!DOCTYPE html>
            <html>
            <center>
            <body bgcolor=e28743 leftmargin=100 rightmargin=100>
                <h1>Pico W<hr>
                <p>Onboard Temperatur:</p> 
                <p>gemessen {temperature} C</p><br> 
                <form action="./aktuell">
                    <input style='height: 100px; width: 200px; font-size: 24px' type="submit" value="aktualisieren" />
                </form><br>
            </body>
            </center></h1>
            </html>
            """
    return str(html)

def serve(connection):
    #Start a web server
    pico_led.off()

    while True:
        client = connection.accept()[0]
        request = client.recv(1024)
        request = str(request)
        try:
            request = request.split()[1]
        except IndexError:
            pass
        if request == '/aktuell?':
            pico_led.on()
            time.sleep(0.25)
            pico_led.off()
        reading = sensor_temp.read_u16() * conversion_factor
        temperature = 27 - (reading - 0.706)/0.001721
        temperature = int(temperature*10 +0.5)/10
        html = webpage(temperature)
        client.send(html)
        client.close()

try:
    ip = connect()
    connection = open_socket(ip)
    serve(connection)
except KeyboardInterrupt:
    machine.reset()